import { CallParameters } from './CallParameters';
import oracledb = require('oracledb');
import { IBasicObject } from './Types';
/**
 * Connects and performs operations on Oracle database
 *
 */
export declare class OracleDB {
    private _connection;
    private _debugLog;
    private _autoCommit;
    constructor();
    initializeConnection(): Promise<void>;
    setTimeout(timeoutInSeconds?: number): void;
    prepareFieldTypesFromMetaData(metaData: oracledb.Metadata[]): IBasicObject<string>;
    fixNumerValues(row: IBasicObject, metaData: IBasicObject<string>): IBasicObject<any>;
    getDataFromCursorInResult(resultSet: oracledb.Result<any>, cursorName?: string, rowsCountToRead?: number): Promise<Array<any>>;
    logExecuteDetails(bindParameters: oracledb.BindParameters, query: string): void;
    closeConection(): Promise<void>;
    get debugLog(): Array<string>;
    execute(query: string, bindParams?: oracledb.BindParameters, options?: oracledb.ExecuteOptions): Promise<oracledb.Result<unknown>>;
    set autoCommit(value: boolean);
    commit(): Promise<void>;
    rollback(): Promise<void>;
    callProcedure(data: CallParameters): Promise<Array<Object>>;
    getDbObjectClass(className: string): Promise<oracledb.DBObjectClass>;
}
export * from './CallParameters';
export * from './BindsDebugger';
export * from './OracleDBErrorParser';
export * from './OracleDBHelper';
export * from './OracleDBRequestParameters';
export * from './Parameters';
export * from './ProcedureFunctionHelper';
